@@ -19,10 +19,10 @@ from autoapi.mappers.python import (
 )
 
 
-def rebuild(confoverrides=None, **kwargs):
+def rebuild(confoverrides=None, confdir=".", **kwargs):
     app = Sphinx(
         srcdir=".",
-        confdir=".",
+        confdir=confdir,
         outdir="_build/text",
         doctreedir="_build/.doctrees",
         buildername="text",
@@ -51,7 +51,11 @@ def builder():
 class TestSimpleModule:
     @pytest.fixture(autouse=True, scope="class")
     def built(self, builder):
-        builder("pyexample")
+        builder(
+            "pyexample",
+            warningiserror=True,
+            confoverrides={"suppress_warnings": ["app"]},
+        )
 
     def test_integration(self):
         self.check_integration("_build/text/autoapi/example/index.txt")
@@ -117,6 +121,40 @@ class TestSimpleModule:
         assert "Bases:" in example_file
 
 
+class TestMovedConfPy(TestSimpleModule):
+    @pytest.fixture(autouse=True, scope="class")
+    def built(self, builder):
+        builder(
+            "pymovedconfpy",
+            confdir="confpy",
+            warningiserror=True,
+            confoverrides={"suppress_warnings": ["app"]},
+        )
+
+
+class TestSimpleModuleDifferentPrimaryDomain:
+    @pytest.fixture(autouse=True, scope="class")
+    def built(self, builder):
+        builder(
+            "pyexample",
+            warningiserror=True,
+            confoverrides={
+                "autoapi_options": [
+                    "members",
+                    "undoc-members",
+                    "private-members",
+                    "special-members",
+                    "imported-members",
+                ],
+                "primary_domain": "cpp",
+                "suppress_warnings": ["app"],
+            },
+        )
+
+    def test_success(self):
+        pass
+
+
 class TestSimpleStubModule:
     @pytest.fixture(autouse=True, scope="class")
     def built(self, builder):
@@ -710,6 +748,9 @@ class TestComplexPackageParallel:
     def built(self, builder):
         builder("pypackagecomplex", parallel=2)
 
+    def test_success(self):
+        pass
+
 
 def test_caching(builder):
     mtimes = (0, 0)
@@ -810,7 +851,7 @@ def test_string_module_attributes(builder):
         example_file = example_handle.read()
 
     code_snippet_contents = [
-        ".. data:: code_snippet",
+        ".. py:data:: code_snippet",
         "   :annotation: = Multiline-String",
         "",
         "    .. raw:: html",
